@@ -29,6 +29,7 @@
 #'  }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
+#' @noRd
 as_rtf_pageby <- function(tbl) {
   # Calculate Number of rows for each entry.
   tbl <- rtf_nrow(tbl)
@@ -57,7 +58,7 @@ as_rtf_pageby <- function(tbl) {
   }
 
   # Number of rows in cells based on column size
-  index <- sort(c(1:nrow(cell_tbl), do.call(rbind, row)$row_start))
+  index <- sort(c(seq_len(nrow(cell_tbl)), do.call(rbind, row)$row_start))
 
   # Number of row in each table entry
   if (is.null(attr(cell_tbl, "cell_nrow"))) {
@@ -102,7 +103,7 @@ as_rtf_pageby <- function(tbl) {
 
     # If the last row is a page by row, move it to next row
     retain <- unlist(lapply(split(page_dict, page), function(x) {
-      rev(cumsum(rev(x$pageby)) == 1:nrow(x))
+      rev(cumsum(rev(x$pageby)) == seq_len(nrow(x)))
     }))
 
     page + retain + 1
@@ -139,10 +140,18 @@ as_rtf_pageby <- function(tbl) {
 
   ## Remove repeated records if group_by is not null
   if (!is.null(group_by)) {
-    cell_tbl <- rtf_group_by_enhance(cell_tbl,
-      group_by = group_by,
+    tmp <- cell_tbl
+    tmp$`.pageby` <- pageby$id
+    tmp$`.order` <- seq_len(nrow(tmp))
+    tmp <- rtf_group_by_enhance(tmp,
+      group_by = c(".pageby", group_by),
       page_index = subset(page_dict, !pageby)$page
     )
+
+    stopifnot(all(seq_len(nrow(tmp)) == tmp$`.order`))
+    tmp <- tmp[, !names(tmp) %in% c(".pageby", ".order"), drop = FALSE]
+    attributes(tmp) <- attributes(cell_tbl)
+    cell_tbl <- tmp
   }
 
   # Add border type for first and last row
@@ -188,7 +197,7 @@ as_rtf_pageby <- function(tbl) {
   rtf_row_encode <- apply(rtf_row, 2, paste, collapse = "\n")
   rtf[page_dict$pageby] <- rtf_row_encode
 
-  page_dict$index <- 1:nrow(page_dict)
+  page_dict$index <- seq_len(nrow(page_dict))
 
   if (pageby$pageby_header) {
     # Show pageby header at the top of each page
@@ -217,7 +226,7 @@ as_rtf_pageby <- function(tbl) {
     page_dict <- rbind(page_dict, pageby_header)
     page_dict_order <- order(page_dict$index)
     page_dict <- page_dict[page_dict_order, ]
-    page_dict$index <- 1:nrow(page_dict)
+    page_dict$index <- seq_len(nrow(page_dict))
 
     # Restructure rtf encoding
     rtf <- c(rtf, rtf_pageby_header)[page_dict_order]
@@ -257,7 +266,8 @@ as_rtf_pageby <- function(tbl) {
 
       # RTF encode for nested header
       rtf_header_nested <- rep("", nrow(pageby_header))
-      for (i in 1:(rtf_nrow$pageby - 1)) {
+
+      for (i in seq_len(rtf_nrow$pageby - 1)) {
         rtf_nested_index <- pageby_header_nested[[pageby$by_var[[i]]]]
 
         rtf_nested <- apply(rtf_row_list[[i]], 2, paste, collapse = "\n")
@@ -270,7 +280,7 @@ as_rtf_pageby <- function(tbl) {
       page_dict <- rbind(page_dict, pageby_header_nested[, names(page_dict)])
       page_dict_order <- order(page_dict$index)
       page_dict <- page_dict[page_dict_order, ]
-      page_dict$index <- 1:nrow(page_dict)
+      page_dict$index <- seq_len(nrow(page_dict))
 
       # Restructure rtf encoding
       rtf <- c(rtf, rtf_header_nested)[page_dict_order]
@@ -281,7 +291,7 @@ as_rtf_pageby <- function(tbl) {
   rtf_index <- page_dict$index[!(page_dict$page_id == "-----" & page_dict$pageby)]
   rtf <- rtf[rtf_index]
   page_dict <- page_dict[rtf_index, ]
-  page_dict$index <- 1:nrow(page_dict)
+  page_dict$index <- seq_len(nrow(page_dict))
 
   attr(rtf, "info") <- page_dict
   rtf
