@@ -1,4 +1,4 @@
-#    Copyright (c) 2020 Merck Sharp & Dohme Corp. a subsidiary of Merck & Co., Inc., Kenilworth, NJ, USA.
+#    Copyright (c) 2022 Merck & Co., Inc., Rahway, NJ, USA and its affiliates. All rights reserved.
 #
 #    This file is part of the r2rtf program.
 #
@@ -73,17 +73,3 @@
 #'
 #' @format A data frame with 1 row and 1 variable.
 "r2rtf_tbl3"
-
-#' Dictionary of Unicode and Latex Code
-#'
-#' A dataset containing the mapping between unicode and latex code.
-#'
-#' @format A data frame with 681 rows and 3 variables.
-#' \describe{
-#'    \item{unicode}{unicode, UTF-8 code}
-#'    \item{latex}{latex, latex code}
-#'    \item{int}{int, Converted integer of the UTF-8 code}
-#' }
-#'
-#' @source \url{http://milde.users.sourceforge.net/LUCR/Math/data/unimathsymbols.txt}
-"unicode_latex"
